
from mmisdk.common.base_model import BaseModel


class BitgoCreateTxExtraParams(BaseModel):
    walletId: str
